@@ -49,13 +49,18 @@ class ItemMonitor(object):
               "status": (item.task_status[task] if task in item.task_status else None)
             })
 
+        if self.pipeline.project:
+            project_name = self.pipeline.project.title
+        else:
+            project_name = None
         item_data = {
           "id": item.item_id,
           "name": ("Item %s" % item["item_name"] if "item_name" in item else "New item"),
           "number": item.item_number,
           "status": self.item_status(),
           "tasks": tasks,
-          "output": "".join(self.collected_data)
+          "output": "".join(self.collected_data),
+          "project": project_name
         }
 
         return item_data
@@ -71,8 +76,10 @@ class ItemMonitor(object):
             return "running"
 
     def handle_item_output(self, item, data):
-        self.collected_data.append(data)
-        SeesawConnection.broadcast("item.output", {"item_id": item.item_id, "data": data})
+        text = data.decode('utf8', 'replace')
+
+        self.collected_data.append(text)
+        SeesawConnection.broadcast("item.output", {"item_id": item.item_id, "data": text})
 
     def handle_item_task_status(self, item, task, new_status, old_status):
         SeesawConnection.broadcast("item.task_status", {"item_id": item.item_id, "task_id": id(task), "new_status": new_status, "old_status": old_status})
